# xpath_utils

![PyPI - package version](https://img.shields.io/pypi/v/xpath_utils?logo=pypi&style=flat-square)
![PyPI - license](https://img.shields.io/pypi/l/xpath_utils?label=package%20license&style=flat-square)
![PyPI - python version](https://img.shields.io/pypi/pyversions/xpath_utils?logo=pypi&style=flat-square)
![PyPI - downloads](https://img.shields.io/pypi/dm/xpath_utils?logo=pypi&style=flat-square)

![GitHub - last commit](https://img.shields.io/github/last-commit/kkristof200/py_xpath_utils?style=flat-square)
![GitHub - commit activity](https://img.shields.io/github/commit-activity/m/kkristof200/py_xpath_utils?style=flat-square)

![GitHub - code size in bytes](https://img.shields.io/github/languages/code-size/kkristof200/py_xpath_utils?style=flat-square)
![GitHub - repo size](https://img.shields.io/github/repo-size/kkristof200/py_xpath_utils?style=flat-square)
![GitHub - lines of code](https://img.shields.io/tokei/lines/github/kkristof200/py_xpath_utils?style=flat-square)

![GitHub - license](https://img.shields.io/github/license/kkristof200/py_xpath_utils?label=repo%20license&style=flat-square)

## Description

A collection of utils for easier creation of xpaths

## Install

~~~~bash
pip install xpath_utils
# or
pip3 install xpath_utils
~~~~

## Usage

~~~~python
import xpath_utils
~~~~

## Dependencies